@@ -14,13 +14,14 @@ use v5.26;
 use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
+use Object::Pad;
 
-package Sys::Async::Virt::DomainCheckpoint v0.0.21;
+class Sys::Async::Virt::DomainCheckpoint v0.1.0;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.21;
+use Protocol::Sys::Virt::Remote::XDR v0.1.0;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -38,35 +39,32 @@ use constant {
 };
 
 
-sub new($class, %args) {
-    return bless {
-        id => $args{id},
-        client => $args{client},
-    }, $class;
-}
+field $_id :param :reader;
+field $_client :param :reader;
 
-sub delete($self, $flags = 0) {
-    return $self->{client}->_call(
+
+method delete($flags = 0) {
+    return $_client->_call(
         $remote->PROC_DOMAIN_CHECKPOINT_DELETE,
-        { checkpoint => $self->{id}, flags => $flags // 0 }, empty => 1 );
+        { checkpoint => $_id, flags => $flags // 0 }, empty => 1 );
 }
 
-async sub get_parent($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method get_parent($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_DOMAIN_CHECKPOINT_GET_PARENT,
-        { checkpoint => $self->{id}, flags => $flags // 0 }, unwrap => 'parent' );
+        { checkpoint => $_id, flags => $flags // 0 }, unwrap => 'parent' );
 }
 
-async sub get_xml_desc($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method get_xml_desc($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_DOMAIN_CHECKPOINT_GET_XML_DESC,
-        { checkpoint => $self->{id}, flags => $flags // 0 }, unwrap => 'xml' );
+        { checkpoint => $_id, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
-async sub list_all_children($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method list_all_children($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_DOMAIN_CHECKPOINT_LIST_ALL_CHILDREN,
-        { checkpoint => $self->{id}, need_results => $remote->DOMAIN_SNAPSHOT_LIST_MAX, flags => $flags // 0 }, unwrap => 'checkpoints' );
+        { checkpoint => $_id, need_results => $remote->DOMAIN_SNAPSHOT_LIST_MAX, flags => $flags // 0 }, unwrap => 'checkpoints' );
 }
 
 
@@ -82,7 +80,7 @@ Sys::Async::Virt::DomainCheckpoint - Client side proxy to remote LibVirt domain
 
 =head1 VERSION
 
-v0.0.21
+v0.1.0
 
 =head1 SYNOPSIS
 
