@@ -14,13 +14,14 @@ use v5.26;
 use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
+use Object::Pad;
 
-package Sys::Async::Virt::NetworkPort v0.0.21;
+class Sys::Async::Virt::NetworkPort v0.1.0;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.21;
+use Protocol::Sys::Virt::Remote::XDR v0.1.0;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -34,40 +35,37 @@ use constant {
 };
 
 
-sub new($class, %args) {
-    return bless {
-        id => $args{id},
-        client => $args{client},
-    }, $class;
-}
+field $_id :param :reader;
+field $_client :param :reader;
 
-sub delete($self, $flags = 0) {
-    return $self->{client}->_call(
+
+method delete($flags = 0) {
+    return $_client->_call(
         $remote->PROC_NETWORK_PORT_DELETE,
-        { port => $self->{id}, flags => $flags // 0 }, empty => 1 );
+        { port => $_id, flags => $flags // 0 }, empty => 1 );
 }
 
-async sub get_parameters($self, $flags = 0) {
-    $flags |= await $self->{client}->_typed_param_string_okay();
-    my $nparams = await $self->{client}->_call(
+async method get_parameters($flags = 0) {
+    $flags |= await $_client->_typed_param_string_okay();
+    my $nparams = await $_client->_call(
         $remote->PROC_NETWORK_PORT_GET_PARAMETERS,
-        { port => $self->{id}, nparams => 0, flags => $flags // 0 }, unwrap => 'nparams' );
-    return await $self->{client}->_call(
+        { port => $_id, nparams => 0, flags => $flags // 0 }, unwrap => 'nparams' );
+    return await $_client->_call(
         $remote->PROC_NETWORK_PORT_GET_PARAMETERS,
-        { port => $self->{id}, nparams => $nparams, flags => $flags // 0 }, unwrap => 'params' );
+        { port => $_id, nparams => $nparams, flags => $flags // 0 }, unwrap => 'params' );
 }
 
-async sub get_xml_desc($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method get_xml_desc($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_NETWORK_PORT_GET_XML_DESC,
-        { port => $self->{id}, flags => $flags // 0 }, unwrap => 'xml' );
+        { port => $_id, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
-async sub set_parameters($self, $params, $flags = 0) {
-    $params = await $self->{client}->_filter_typed_param_string( $params );
-    return await $self->{client}->_call(
+async method set_parameters($params, $flags = 0) {
+    $params = await $_client->_filter_typed_param_string( $params );
+    return await $_client->_call(
         $remote->PROC_NETWORK_PORT_SET_PARAMETERS,
-        { port => $self->{id}, params => $params, flags => $flags // 0 }, empty => 1 );
+        { port => $_id, params => $params, flags => $flags // 0 }, empty => 1 );
 }
 
 
@@ -83,7 +81,7 @@ Sys::Async::Virt::NetworkPort - Client side proxy to remote LibVirt network port
 
 =head1 VERSION
 
-v0.0.21
+v0.1.0
 
 =head1 SYNOPSIS
 
@@ -162,4 +160,4 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
   Copyright (C) 2024-2025 Erik Huelsmann
 
 All rights reserved. This program is free software;
-you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+you can redistribute it and/or modify it under the same terms as Perl itself.
