@@ -14,34 +14,32 @@ use v5.26;
 use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
+use Object::Pad;
 
-package Sys::Async::Virt::NwFilter v0.0.21;
+class Sys::Async::Virt::NwFilter v0.1.0;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.21;
+use Protocol::Sys::Virt::Remote::XDR v0.1.0;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 
 
-sub new($class, %args) {
-    return bless {
-        id => $args{id},
-        client => $args{client},
-    }, $class;
-}
+field $_id :param :reader;
+field $_client :param :reader;
 
-async sub get_xml_desc($self, $flags = 0) {
-    return await $self->{client}->_call(
+
+async method get_xml_desc($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_NWFILTER_GET_XML_DESC,
-        { nwfilter => $self->{id}, flags => $flags // 0 }, unwrap => 'xml' );
+        { nwfilter => $_id, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
-sub undefine($self) {
-    return $self->{client}->_call(
+method undefine() {
+    return $_client->_call(
         $remote->PROC_NWFILTER_UNDEFINE,
-        { nwfilter => $self->{id} }, empty => 1 );
+        { nwfilter => $_id }, empty => 1 );
 }
 
 
@@ -56,7 +54,7 @@ Sys::Async::Virt::NwFilter - Client side proxy to remote LibVirt network filter
 
 =head1 VERSION
 
-v0.0.21
+v0.1.0
 
 =head1 SYNOPSIS
 
@@ -108,4 +106,4 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
   Copyright (C) 2024-2025 Erik Huelsmann
 
 All rights reserved. This program is free software;
-you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+you can redistribute it and/or modify it under the same terms as Perl itself.
