@@ -14,13 +14,14 @@ use v5.26;
 use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
+use Object::Pad;
 
-package Sys::Async::Virt::Secret v0.0.21;
+class Sys::Async::Virt::Secret v0.1.0;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.21;
+use Protocol::Sys::Virt::Remote::XDR v0.1.0;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -29,36 +30,32 @@ use constant {
 };
 
 
-sub new($class, %args) {
-    return bless {
-        id => $args{id},
-        client => $args{client},
-    }, $class;
-}
+field $_id :param :reader;
+field $_client :param :reader;
 
 
-async sub get_value($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method get_value($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_SECRET_GET_VALUE,
-        { secret => $self->{id}, flags => $flags // 0 }, unwrap => 'value' );
+        { secret => $_id, flags => $flags // 0 }, unwrap => 'value' );
 }
 
-async sub get_xml_desc($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method get_xml_desc($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_SECRET_GET_XML_DESC,
-        { secret => $self->{id}, flags => $flags // 0 }, unwrap => 'xml' );
+        { secret => $_id, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
-sub set_value($self, $value, $flags = 0) {
-    return $self->{client}->_call(
+method set_value($value, $flags = 0) {
+    return $_client->_call(
         $remote->PROC_SECRET_SET_VALUE,
-        { secret => $self->{id}, value => $value, flags => $flags // 0 }, empty => 1 );
+        { secret => $_id, value => $value, flags => $flags // 0 }, empty => 1 );
 }
 
-sub undefine($self) {
-    return $self->{client}->_call(
+method undefine() {
+    return $_client->_call(
         $remote->PROC_SECRET_UNDEFINE,
-        { secret => $self->{id} }, empty => 1 );
+        { secret => $_id }, empty => 1 );
 }
 
 
@@ -74,7 +71,7 @@ Sys::Async::Virt::Secret - Client side proxy to remote LibVirt secret
 
 =head1 VERSION
 
-v0.0.21
+v0.1.0
 
 =head1 SYNOPSIS
 
