@@ -14,13 +14,14 @@ use v5.26;
 use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
+use Object::Pad;
 
-package Sys::Async::Virt::StoragePool v0.0.21;
+class Sys::Async::Virt::StoragePool v0.1.0;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.21;
+use Protocol::Sys::Virt::Remote::XDR v0.1.0;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -46,119 +47,116 @@ use constant {
 };
 
 
-sub new($class, %args) {
-    return bless {
-        id => $args{id},
-        client => $args{client},
-    }, $class;
-}
+field $_id :param :reader;
+field $_client :param :reader;
 
-sub build($self, $flags = 0) {
-    return $self->{client}->_call(
+
+method build($flags = 0) {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_BUILD,
-        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
+        { pool => $_id, flags => $flags // 0 }, empty => 1 );
 }
 
-sub create($self, $flags = 0) {
-    return $self->{client}->_call(
+method create($flags = 0) {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_CREATE,
-        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
+        { pool => $_id, flags => $flags // 0 }, empty => 1 );
 }
 
-sub delete($self, $flags = 0) {
-    return $self->{client}->_call(
+method delete($flags = 0) {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_DELETE,
-        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
+        { pool => $_id, flags => $flags // 0 }, empty => 1 );
 }
 
-sub destroy($self) {
-    return $self->{client}->_call(
+method destroy() {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_DESTROY,
-        { pool => $self->{id} }, empty => 1 );
+        { pool => $_id }, empty => 1 );
 }
 
-async sub get_autostart($self) {
-    return await $self->{client}->_call(
+async method get_autostart() {
+    return await $_client->_call(
         $remote->PROC_STORAGE_POOL_GET_AUTOSTART,
-        { pool => $self->{id} }, unwrap => 'autostart' );
+        { pool => $_id }, unwrap => 'autostart' );
 }
 
-sub get_info($self) {
-    return $self->{client}->_call(
+method get_info() {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_GET_INFO,
-        { pool => $self->{id} } );
+        { pool => $_id } );
 }
 
-async sub get_xml_desc($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method get_xml_desc($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_STORAGE_POOL_GET_XML_DESC,
-        { pool => $self->{id}, flags => $flags // 0 }, unwrap => 'xml' );
+        { pool => $_id, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
-async sub is_active($self) {
-    return await $self->{client}->_call(
+async method is_active() {
+    return await $_client->_call(
         $remote->PROC_STORAGE_POOL_IS_ACTIVE,
-        { pool => $self->{id} }, unwrap => 'active' );
+        { pool => $_id }, unwrap => 'active' );
 }
 
-async sub is_persistent($self) {
-    return await $self->{client}->_call(
+async method is_persistent() {
+    return await $_client->_call(
         $remote->PROC_STORAGE_POOL_IS_PERSISTENT,
-        { pool => $self->{id} }, unwrap => 'persistent' );
+        { pool => $_id }, unwrap => 'persistent' );
 }
 
-async sub list_all_volumes($self, $flags = 0) {
-    return await $self->{client}->_call(
+async method list_all_volumes($flags = 0) {
+    return await $_client->_call(
         $remote->PROC_STORAGE_POOL_LIST_ALL_VOLUMES,
-        { pool => $self->{id}, need_results => $remote->STORAGE_VOL_LIST_MAX, flags => $flags // 0 }, unwrap => 'vols' );
+        { pool => $_id, need_results => $remote->STORAGE_VOL_LIST_MAX, flags => $flags // 0 }, unwrap => 'vols' );
 }
 
-async sub list_volumes($self) {
-    return await $self->{client}->_call(
+async method list_volumes() {
+    return await $_client->_call(
         $remote->PROC_STORAGE_POOL_LIST_VOLUMES,
-        { pool => $self->{id}, maxnames => $remote->STORAGE_VOL_LIST_MAX }, unwrap => 'names' );
+        { pool => $_id, maxnames => $remote->STORAGE_VOL_LIST_MAX }, unwrap => 'names' );
 }
 
-async sub num_of_volumes($self) {
-    return await $self->{client}->_call(
+async method num_of_volumes() {
+    return await $_client->_call(
         $remote->PROC_STORAGE_POOL_NUM_OF_VOLUMES,
-        { pool => $self->{id} }, unwrap => 'num' );
+        { pool => $_id }, unwrap => 'num' );
 }
 
-sub refresh($self, $flags = 0) {
-    return $self->{client}->_call(
+method refresh($flags = 0) {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_REFRESH,
-        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
+        { pool => $_id, flags => $flags // 0 }, empty => 1 );
 }
 
-sub set_autostart($self, $autostart) {
-    return $self->{client}->_call(
+method set_autostart($autostart) {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_SET_AUTOSTART,
-        { pool => $self->{id}, autostart => $autostart }, empty => 1 );
+        { pool => $_id, autostart => $autostart }, empty => 1 );
 }
 
-sub undefine($self) {
-    return $self->{client}->_call(
+method undefine() {
+    return $_client->_call(
         $remote->PROC_STORAGE_POOL_UNDEFINE,
-        { pool => $self->{id} }, empty => 1 );
+        { pool => $_id }, empty => 1 );
 }
 
-async sub vol_create_xml($self, $xml, $flags = 0) {
-    return await $self->{client}->_call(
+async method vol_create_xml($xml, $flags = 0) {
+    return await $_client->_call(
         $remote->PROC_STORAGE_VOL_CREATE_XML,
-        { pool => $self->{id}, xml => $xml, flags => $flags // 0 }, unwrap => 'vol' );
+        { pool => $_id, xml => $xml, flags => $flags // 0 }, unwrap => 'vol' );
 }
 
-async sub vol_create_xml_from($self, $xml, $clonevol, $flags = 0) {
-    return await $self->{client}->_call(
+async method vol_create_xml_from($xml, $clonevol, $flags = 0) {
+    return await $_client->_call(
         $remote->PROC_STORAGE_VOL_CREATE_XML_FROM,
-        { pool => $self->{id}, xml => $xml, clonevol => $clonevol, flags => $flags // 0 }, unwrap => 'vol' );
+        { pool => $_id, xml => $xml, clonevol => $clonevol, flags => $flags // 0 }, unwrap => 'vol' );
 }
 
-async sub vol_lookup_by_name($self, $name) {
-    return await $self->{client}->_call(
+async method vol_lookup_by_name($name) {
+    return await $_client->_call(
         $remote->PROC_STORAGE_VOL_LOOKUP_BY_NAME,
-        { pool => $self->{id}, name => $name }, unwrap => 'vol' );
+        { pool => $_id, name => $name }, unwrap => 'vol' );
 }
 
 
@@ -174,7 +172,7 @@ Sys::Async::Virt::StoragePool - Client side proxy to remote LibVirt storage pool
 
 =head1 VERSION
 
-v0.0.21
+v0.1.0
 
 =head1 SYNOPSIS
 
@@ -384,4 +382,4 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
   Copyright (C) 2024-2025 Erik Huelsmann
 
 All rights reserved. This program is free software;
-you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+you can redistribute it and/or modify it under the same terms as Perl itself.
